@@ -20,12 +20,12 @@ sibling = '[[!my $sibling=#ONT(sibling)]]'
 work = '[[!my {work,job,boss}]]'
 school = '[[!my {school,college,university}]]'
 pet = '[my cat]'
-repeat = '{' \
+repeat = '<{' \
          '[![!{can,will,could} you]? repeat, {that,what you said,you said}?],' \
          '[![!{can,will,could} you]? say {that,it} again],' \
          '[!what did you, just? say],' \
          '[!what was that]' \
-         '} #COPY(__goal_return_state__)'
+         '}, #CNC(movies), #CNC(music), #CNC(nba), #CNC(news)> #COPY(__goal_return_state__)'
 
 global_update_rules = {
     '#CONTRACTIONS': '',
