@@ -132,7 +132,8 @@ system = {
                     'state': 'pet_type_err',
 
                     '`Well, that\'s interesting. I don\'t seem to know that kind of '
-                    'animal. It must be pretty special. `':
+                    'animal. It must be pretty special. `'
+                    '#SET($pet_type=pet)':
                         'ask_favorite_thing'
                 }
             }
@@ -717,7 +718,7 @@ general_pet = {
 
                 '`You know, I think I am doing a good job taking care of my dog, but she doesn\'t '
                 'seem to want to spend much time with me. She really is a bit of a loner. `'
-                '#GSRET(pet_attachment)': {
+                '#GSRET(ask_pet_attachment)': {
                     'state': 'emora_dog',
 
                     '[{sorry,sad,sucks,stinks,unfortunate,good luck,warm up,[give,time]}]':{
