@@ -4,13 +4,13 @@ from emora_stdm import DialogueFlow
 
 house = DialogueFlow('_local_start')
 house.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
-house.knowledge_base().load_json_file(PATHDIR.replace('__***__','house.json'))
 house.add_system_transition('_local_start', 'start', '#RAND(life_in,True)')
 
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($life_in=True) #ANY($is_student=False,$is_student=None)',
+    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($life_in=True,$life_started=True) '
+             '#ANY($relationship_status=married,$relationship_status=divorced,$partner=husband,$partner=wife)',
 
     '`Do you want to know something? I can\'t stop thinking about my day yesterday. '
     'My friends came over to my new apartment for the first time and it was so much fun.`'
@@ -341,7 +341,7 @@ user_living = {
                     '`It\'s tough to be in a place that doesn\'t feel like home. I know I hated the last place I was living.`'
                     '#GSRET(school_proximity)':{
 
-                        '[why]': {
+                        '[{why,[what,about,{that,it}]}]': {
 
                             '`It was just really, really small and dark. I couldn\'t even have people over because '
                             'of the small space. `'
@@ -500,6 +500,11 @@ live_with = {
 
     '#DEFAULT `Wait, do you live with anyone?`': 'live_with_response',
 
+    '#ANY($relationship_status=married,$partner=husband,$partner=wife,$partner=spouse)':{
+        'state': 'exit',
+        'score': 1.1
+    },
+
     '`You know, sometimes I can get lonely because I don\'t have any roommates, '
     'even though I do have friends and family come over a lot. Do you live with anyone?`'
     '#GATE': {
@@ -539,7 +544,7 @@ live_with = {
                 '#UNX':{
                     'state': 'get_along_unx',
 
-                    '`To be fair, I think every household has its ups and downs. `': 'exit'
+                    '`To be fair, I think every household has its ups and downs. Anyway, `': 'exit'
                 }
             }
         },
@@ -563,13 +568,13 @@ live_with = {
                 '#AGREE': {
                     'state': 'likes_lives_alone',
 
-                    '`It definitely has it\'s benefits, doesn\'t it?`': 'exit'
+                    '`It definitely has it\'s benefits, doesn\'t it? Anyway, `': 'exit'
                 },
 
                 '#DISAGREE':{
                     'state': 'hates_lives_alone',
 
-                    '`I understand that. It can be kind of boring.`': 'exit'
+                    '`I understand that. It can be kind of boring. Anyway, `': 'exit'
                 },
 
                 '#UNX': 'exit'
@@ -600,7 +605,10 @@ user = {
 
         '`It was just this small apartment, nothing special.`': {
 
-            '#UNX': {'`Honestly, I am pretty glad to be out of it. ` #GRET': 'exit'}
+            '#UNX': {
+
+                '`Honestly, I am pretty glad to be out of it. ` #GRET': 'exit'
+            }
         }
     },
 
