@@ -5,12 +5,11 @@ from emora_stdm import DialogueFlow
 
 work = DialogueFlow('_local_start')
 work.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
-work.knowledge_base().load_json_file(PATHDIR.replace('__***__', 'work.json'))
 work.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(work) #GOAL(work) #IF($life_in=True) #ANY($is_student=False,$is_student=None)',
+    'enter': '#GATE #GCOM(work) #GOAL(work) #IF($life_in=True,$life_started=True) #ANY($is_student=False,$is_student=None)',
 
     '#IF($is_employed=False) #SCORE(1.1) `So, I remember you said you don\'t have a job. `': 'younger_job_wish',
 
@@ -28,7 +27,7 @@ system = {
         '[$job=#ONT(_job)]'
         '#SET($is_employed=True)': {
             'state': 'job_match_ont',
-            'score': 1.2,
+            'score': 1.1,
 
             '`Oh, you\'re a ` $job `?`': {
                 'state': 'like_job_question',
@@ -109,7 +108,7 @@ system = {
         '}, $job_dept=#ONT(_job department)]'
         '#SET($is_employed=True)':{
             'state': 'job_department',
-            'score': 1.1,
+            'score': 1.2,
 
             '`You do ` $job_dept `?`': 'like_job_question'
         },
@@ -120,7 +119,7 @@ system = {
         '}, $job_loc=#ONT(_job location)]'
         '#SET($is_employed=True)': {
             'state': 'job_location',
-            'score': 1.1,
+            'score': 1.2,
 
             '`You work at a ` $job_loc `?`': 'like_job_question'
         },
@@ -157,7 +156,7 @@ job_wishes = {
         '#UNX': {
             'state': 'younger_job_wish',
 
-            '`So, this is a fun question. When you were younger, what did you want to be when you grew up?`'
+            '`This is a fun question. When you were younger, what did you want to be when you grew up?`'
             '#GSRET(emoras_job_wish)': {
 
                 '{[$younger_job_wish=#ONT(_job)], [a, #POS(noun)]}': {
